path

package
v0.2.0-alpha Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 18, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

This package provides an interface to functions and structs in the standard path package to facilitate mocking.

Index

Constants

This section is empty.

Variables

var (
	Base  = path.Base
	Clean = path.Clean
	Dir   = path.Dir
	Ext   = path.Ext
	IsAbs = path.IsAbs
	Join  = path.Join
	Match = path.Match
	Split = path.Split
)
var (
	ErrBadPattern = path.ErrBadPattern
)

Functions

func NewPath

func NewPath() pathFacade

Types

type Path

type Path interface {
	Base(string) string
	Clean(string) string
	Dir(string) string
	Ext(string) string
	IsAbs(string) bool
	Join(...string) string
	Match(string, string) (bool, error)
	Split(string) (string, string)
}

Directories

Path Synopsis
This package provides an interface to functions and structs in the standard path/filepath package to facilitate mocking.
This package provides an interface to functions and structs in the standard path/filepath package to facilitate mocking.

Jump to